@@ -4,13 +4,13 @@
  * The license is same as the one on the root.
 */
 
-use crate::header::{
+use crate::definitions::{
     Pipeline, Shaders, Textures, UniformBuffer, UniformBuffers, Vertex, VertexBuffers,
 };
 use image::GenericImageView;
-use wgpu::{util::DeviceExt, BindGroupLayout};
+use wgpu::util::DeviceExt;
 
-impl crate::header::Renderer {
+impl crate::definitions::Renderer {
     /// Creates and adds the pipeline to render queue
     pub fn build_and_append_pipeline(
         &mut self,
@@ -20,12 +20,7 @@ impl crate::header::Renderer {
         uniform_index: Option<usize>,
     ) -> Result<usize, anyhow::Error> {
         let pipe = self
-            .build_pipeline(
-                shader_index,
-                vertex_buffer_index,
-                texture_index,
-                uniform_index,
-            )
+            .build_pipeline(shader_index, vertex_buffer_index, texture_index, uniform_index)
             .expect("Couldn't Create Render Pipeline");
         self.render_pipelines.push(pipe);
         Ok(self.render_pipelines.len() - 1)
@@ -65,16 +60,15 @@ impl crate::header::Renderer {
     }
 }
 
-impl crate::header::Renderer {
+impl crate::definitions::Renderer {
     /// Creates and adds the shaders to render queue
     pub fn build_and_append_shaders(
         &mut self,
         name: &'static str,
         shader_source: String,
-        uniform_layout: Option<&BindGroupLayout>,
     ) -> Result<usize, anyhow::Error> {
         let shaders = self
-            .build_shaders(name, shader_source, uniform_layout)
+            .build_shaders(name, shader_source)
             .expect("Couldn't create shaders");
         let index = self.shaders.len();
         self.shaders.push(shaders);
@@ -86,26 +80,22 @@ impl crate::header::Renderer {
         &mut self,
         name: &str,
         shader_source: String,
-        uniform_layout: Option<&BindGroupLayout>,
     ) -> Result<Shaders, anyhow::Error> {
         let shader = self
             .device
             .create_shader_module(&wgpu::ShaderModuleDescriptor {
                 label: Some("Shader"),
                 source: wgpu::ShaderSource::Wgsl(shader_source.into()),
-                //flags: wgpu::ShaderFlags::all(),
+                flags: wgpu::ShaderFlags::all(),
             });
-
-        let mut bind_group_layouts = vec![&self.texture_bind_group_layout, &self.default_uniform_bind_group_layout];
-        if uniform_layout.is_some() {
-            bind_group_layouts.push(uniform_layout.unwrap())
-        }
-
         let render_pipeline_layout =
             self.device
                 .create_pipeline_layout(&wgpu::PipelineLayoutDescriptor {
                     label: Some("Render Pipeline Layout"),
-                    bind_group_layouts: &bind_group_layouts.as_slice(),
+                    bind_group_layouts: &[
+                        &self.texture_bind_group_layout,
+                        &self.uniform_bind_group_layout,
+                    ],
                     push_constant_ranges: &[],
                 });
 
@@ -123,8 +113,8 @@ impl crate::header::Renderer {
                     module: &shader,
                     entry_point: "main",
                     targets: &[wgpu::ColorTargetState {
-                        format: self.config.format,
-                        write_mask: wgpu::ColorWrites::ALL,
+                        format: self.sc_desc.format,
+                        write_mask: wgpu::ColorWrite::ALL,
                         blend: Some(wgpu::BlendState::REPLACE),
                     }],
                 }),
@@ -132,7 +122,7 @@ impl crate::header::Renderer {
                     topology: wgpu::PrimitiveTopology::TriangleList,
                     strip_index_format: None,
                     front_face: wgpu::FrontFace::Ccw,
-                    cull_mode: None,//Some(wgpu::Face::Back),
+                    cull_mode: Some(wgpu::Face::Back),
                     polygon_mode: wgpu::PolygonMode::Fill,
                     clamp_depth: false,
                     conservative: false,
@@ -167,7 +157,7 @@ impl crate::header::Renderer {
     }
 }
 
-impl crate::header::Renderer {
+impl crate::definitions::Renderer {
     /// Creates and adds the vertex buffers to render queue
     pub fn build_and_append_vertex_buffers(
         &mut self,
@@ -193,7 +183,7 @@ impl crate::header::Renderer {
             .create_buffer_init(&wgpu::util::BufferInitDescriptor {
                 label: Some("Vertex Buffer"),
                 contents: bytemuck::cast_slice(verticies.as_slice()),
-                usage: wgpu::BufferUsages::VERTEX,
+                usage: wgpu::BufferUsage::VERTEX,
             });
 
         let index_buffer = self
@@ -201,7 +191,7 @@ impl crate::header::Renderer {
             .create_buffer_init(&wgpu::util::BufferInitDescriptor {
                 label: Some("Index Buffer"),
                 contents: bytemuck::cast_slice(indicies.as_slice()),
-                usage: wgpu::BufferUsages::INDEX,
+                usage: wgpu::BufferUsage::INDEX,
             });
 
         Ok(VertexBuffers {
@@ -233,25 +223,25 @@ impl crate::header::Renderer {
     }
 }
 
-impl crate::header::Renderer {
+impl crate::definitions::Renderer {
     /// Creates and adds the uniform buffers to render queue
     pub fn build_and_append_uniform_buffers(
         &mut self,
         uniforms: Vec<UniformBuffer>,
-    ) -> Result<(usize, BindGroupLayout), anyhow::Error> {
+    ) -> Result<usize, anyhow::Error> {
         let uniform_buffers = self
             .build_uniform_buffer(uniforms)
             .expect("Couldn't create uniform buffer");
         let index = self.shaders.len();
-        self.uniform_bind_group.push(uniform_buffers.0);
-        Ok((index, uniform_buffers.1))
+        self.uniform_bind_group.push(uniform_buffers);
+        Ok(index)
     }
 
     /// Creates a new uniform buffer group, according to a list of types
     pub fn build_uniform_buffer(
         &mut self,
         uniforms: Vec<UniformBuffer>,
-    ) -> Result<(UniformBuffers, BindGroupLayout), anyhow::Error> {
+    ) -> Result<UniformBuffers, anyhow::Error> {
         let mut buffer_entry = Vec::<wgpu::BindGroupEntry>::new();
         let mut buffer_layout = Vec::<wgpu::BindGroupLayoutEntry>::new();
         let mut buffer_vec = Vec::<wgpu::Buffer>::new();
@@ -262,7 +252,7 @@ impl crate::header::Renderer {
                         &wgpu::util::BufferInitDescriptor {
                             label: Some(*name),
                             contents: bytemuck::cast_slice(&[*value]),
-                            usage: wgpu::BufferUsages::UNIFORM,
+                            usage: wgpu::BufferUsage::UNIFORM,
                         },
                     ));
                 }
@@ -271,7 +261,7 @@ impl crate::header::Renderer {
                         &wgpu::util::BufferInitDescriptor {
                             label: Some(*name),
                             contents: bytemuck::cast_slice(&[*value]),
-                            usage: wgpu::BufferUsages::UNIFORM,
+                            usage: wgpu::BufferUsage::UNIFORM,
                         },
                     ));
                 }
@@ -280,7 +270,7 @@ impl crate::header::Renderer {
                         &wgpu::util::BufferInitDescriptor {
                             label: Some(*name),
                             contents: bytemuck::cast_slice(&[*value]),
-                            usage: wgpu::BufferUsages::UNIFORM | wgpu::BufferUsages::COPY_DST,
+                            usage: wgpu::BufferUsage::UNIFORM | wgpu::BufferUsage::COPY_DST,
                         },
                     ));
                 }
@@ -298,7 +288,7 @@ impl crate::header::Renderer {
             buffer_entry.push(descriptor);
             buffer_layout.push(wgpu::BindGroupLayoutEntry {
                 binding: i as u32,
-                visibility: wgpu::ShaderStages::VERTEX | wgpu::ShaderStages::FRAGMENT,
+                visibility: wgpu::ShaderStage::VERTEX | wgpu::ShaderStage::FRAGMENT,
                 ty: wgpu::BindingType::Buffer {
                     ty: wgpu::BufferBindingType::Uniform,
                     has_dynamic_offset: false,
@@ -314,14 +304,15 @@ impl crate::header::Renderer {
                     label: Some("uniform dynamic bind group layout"),
                     entries: &buffer_layout.as_slice(),
                 });
+        self.uniform_bind_group_layout = uniform_bind_group_layout;
 
         let uniform_bind_group = self.device.create_bind_group(&wgpu::BindGroupDescriptor {
             label: Some("Uniform Bind Groups"),
-            layout: &uniform_bind_group_layout,
+            layout: &self.uniform_bind_group_layout,
             entries: &buffer_entry.as_slice(),
         });
 
-        Ok((uniform_bind_group, uniform_bind_group_layout))
+        Ok(uniform_bind_group)
     }
 
     /// Appends a uniform buffer to render queue
@@ -341,7 +332,7 @@ impl crate::header::Renderer {
     }
 }
 
-impl crate::header::Renderer {
+impl crate::definitions::Renderer {
     /// Creates and adds the texture to render queue
     pub fn build_and_append_texture(
         &mut self,
@@ -393,7 +384,7 @@ impl crate::header::Renderer {
             sample_count: 1,
             dimension: wgpu::TextureDimension::D2,
             format: wgpu::TextureFormat::Rgba8UnormSrgb,
-            usage: wgpu::TextureUsages::TEXTURE_BINDING | wgpu::TextureUsages::COPY_DST,
+            usage: wgpu::TextureUsage::SAMPLED | wgpu::TextureUsage::COPY_DST,
         });
 
         self.queue.write_texture(
@@ -401,7 +392,7 @@ impl crate::header::Renderer {
                 texture: &texture,
                 mip_level: 0,
                 origin: wgpu::Origin3d::ZERO,
-                aspect: wgpu::TextureAspect::All,
+                //aspect: wgpu::TextureAspect::All,
             },
             rgba,
             wgpu::ImageDataLayout {
