@@ -48,54 +48,6 @@ pub mod uniform_type {
         pub fn update(&mut self, uniform: Matrix) {
             self.data = uniform.data;
         }
-
-        pub fn from_glm(matrix: glm::Matrix4<f32>) -> Matrix {
-            let mtx = matrix.as_array();
-            Matrix {
-                data: [
-                    [mtx[0][0], mtx[0][1], mtx[0][2], mtx[0][3]],
-                    [mtx[1][0], mtx[1][1], mtx[1][2], mtx[1][3]],
-                    [mtx[2][0], mtx[2][1], mtx[2][2], mtx[2][3]],
-                    [mtx[3][0], mtx[3][1], mtx[3][2], mtx[3][3]],
-                ],
-            }
-        }
-    }
-    impl std::ops::Mul for Matrix {
-        type Output = Matrix;
-
-        fn mul(self, rhs: Self) -> Self::Output {
-            let a = self.data;
-            let b = rhs.data;
-            Matrix {
-                data: [
-                    [
-                        a[0][0] * b[0][0],
-                        a[0][1] * b[1][0],
-                        a[0][2] * b[2][0],
-                        a[0][3] * b[3][0],
-                    ],
-                    [
-                        a[1][0] * b[0][1],
-                        a[1][1] * b[1][1],
-                        a[1][2] * b[2][1],
-                        a[1][3] * b[3][1],
-                    ],
-                    [
-                        a[2][0] * b[0][2],
-                        a[2][1] * b[1][2],
-                        a[2][2] * b[2][2],
-                        a[2][3] * b[3][2],
-                    ],
-                    [
-                        a[3][0] * b[0][3],
-                        a[3][1] * b[1][3],
-                        a[3][2] * b[2][3],
-                        a[3][3] * b[3][3],
-                    ],
-                ],
-            }
-        }
     }
 
     /// An array with length 4, each 32 bit float value, uniform buffer
@@ -125,8 +77,8 @@ pub mod uniform_type {
 
 pub struct Object {
     pub name: Option<&'static str>,
-    pub vertices: Vec<Vertex>,
-    pub indices: Vec<u16>,
+    pub verticies: Vec<Vertex>,
+    pub indicies: Vec<u16>,
     pub pipeline: Pipeline,
     pub pipeline_id: Option<usize>,
     pub window_size: winit::dpi::PhysicalSize<u32>,
@@ -134,8 +86,6 @@ pub struct Object {
     pub height: f32,
     pub depth: f32,
     pub changed: bool,
-    pub transformation_matrix: glm::Matrix4<f32>,
-    pub color: uniform_type::Array,
 }
 
 pub struct Engine {
@@ -143,7 +93,6 @@ pub struct Engine {
     pub event_loop: winit::event_loop::EventLoop<()>,
     pub window: winit::window::Window,
     pub objects: Vec<Object>,
-    pub camera: Camera,
 }
 
 // Container for pipeline values. Each pipeline takes only 1 vertex shader, 1 fragment shader, 1 texture data, and optionally a vector of uniform data.
@@ -175,7 +124,7 @@ pub struct Renderer {
     pub(crate) swap_chain: wgpu::SwapChain,
     pub size: winit::dpi::PhysicalSize<u32>,
     pub(crate) texture_bind_group_layout: wgpu::BindGroupLayout,
-    pub(crate) default_uniform_bind_group_layout: wgpu::BindGroupLayout,
+    pub(crate) uniform_bind_group_layout: wgpu::BindGroupLayout,
     pub(crate) shaders: Vec<Shaders>,
     pub(crate) vertex_buffers: Vec<VertexBuffers>,
     pub(crate) texture_bind_group: Vec<Textures>,
@@ -196,37 +145,19 @@ pub struct WindowDescriptor {
     /// Should the window be resizable
     pub resizable: bool,
 }
-impl std::default::Default for WindowDescriptor {
+impl WindowDescriptor {
     /// Will quickly create a window with default settings
-    fn default() -> Self {
-        Self {
+    pub fn default() -> Result<Self, anyhow::Error> {
+        Ok(Self {
             width: 800.0,
             height: 600.0,
-            title: "Blue Engine",
+            title: "Blue Engine by Blue Mazar",
             decorations: true,
             resizable: true,
-        }
+        })
     }
 }
 
-/// Container for the camera feature. The settings here are needed for
-/// algebra equations needed for camera vision and movement. Please leave it to the renderer to handle
-#[derive(Debug, Clone, Copy)]
-pub struct Camera {
-    /// The position of the camera in 3D space
-    pub eye: glm::Vector3<f32>,
-    /// The target at which the camera should be looking
-    pub target: glm::Vector3<f32>,
-    pub up: glm::Vector3<f32>,
-    pub aspect: f32,
-    /// The field of view of the camera
-    pub fovy: f32,
-    /// The closest view of camera
-    pub znear: f32,
-    /// The furthest view of camera
-    pub zfar: f32,
-}
-
 /// The mouse button identifier
 pub use winit::event::MouseButton;
 /// Keyboard keys identifier
@@ -240,6 +171,14 @@ pub enum UniformBuffer {
     Float(&'static str, uniform_type::Float),
 }
 
+#[rustfmt::skip]
+pub const OPENGL_TO_WGPU_MATRIX: cgmath::Matrix4<f32> = cgmath::Matrix4::new(
+    1.0, 0.0, 0.0, 0.0, 
+    0.0, 1.0, 0.0, 0.0,
+    0.0, 0.0, 0.5, 0.0,
+    0.0, 0.0, 0.5, 1.0
+);
+
 pub fn normalize(value: f32, max: u32) -> f32 {
     let mut result = value / max as f32;
 
