@@ -4,7 +4,7 @@
  * The license is same as the one on the root.
 */
 
-use crate::header::Renderer;
+use crate::definitions::Renderer;
 use anyhow::Result;
 use wgpu::Features;
 use winit::window::Window;
@@ -14,7 +14,7 @@ impl Renderer {
         let size = window.inner_size();
 
         // The instance is a handle to our GPU
-        let instance = wgpu::Instance::new(wgpu::Backends::all());
+        let instance = wgpu::Instance::new(wgpu::BackendBit::PRIMARY);
         let surface = unsafe { instance.create_surface(window) };
         let adapter = instance
             .request_adapter(&wgpu::RequestAdapterOptions {
@@ -36,21 +36,21 @@ impl Renderer {
             .await
             .unwrap();
 
-        let config = wgpu::SurfaceConfiguration {
-            usage: wgpu::TextureUsages::RENDER_ATTACHMENT,
+        let sc_desc = wgpu::SwapChainDescriptor {
+            usage: wgpu::TextureUsage::RENDER_ATTACHMENT,
             format: wgpu::TextureFormat::Bgra8UnormSrgb,
             width: size.width,
             height: size.height,
             present_mode: wgpu::PresentMode::Fifo,
         };
-        surface.configure(&device, &config);
+        let swap_chain = device.create_swap_chain(&surface, &sc_desc);
 
         let texture_bind_group_layout =
             device.create_bind_group_layout(&wgpu::BindGroupLayoutDescriptor {
                 entries: &[
                     wgpu::BindGroupLayoutEntry {
                         binding: 0,
-                        visibility: wgpu::ShaderStages::FRAGMENT,
+                        visibility: wgpu::ShaderStage::FRAGMENT,
                         ty: wgpu::BindingType::Texture {
                             sample_type: wgpu::TextureSampleType::Float { filterable: true },
                             view_dimension: wgpu::TextureViewDimension::D2,
@@ -60,7 +60,7 @@ impl Renderer {
                     },
                     wgpu::BindGroupLayoutEntry {
                         binding: 1,
-                        visibility: wgpu::ShaderStages::FRAGMENT,
+                        visibility: wgpu::ShaderStage::FRAGMENT,
                         ty: wgpu::BindingType::Sampler {
                             comparison: false,
                             filtering: true,
@@ -71,42 +71,22 @@ impl Renderer {
                 label: Some("texture_bind_group_layout"),
             });
 
-        let default_uniform_bind_group_layout =
+        let uniform_bind_group_layout =
             device.create_bind_group_layout(&wgpu::BindGroupLayoutDescriptor {
                 label: Some("uniform dynamic bind group layout"),
-                entries: &[
-                    wgpu::BindGroupLayoutEntry {
-                        binding: 0,
-                        visibility: wgpu::ShaderStages::VERTEX | wgpu::ShaderStages::FRAGMENT,
-                        ty: wgpu::BindingType::Buffer {
-                            ty: wgpu::BufferBindingType::Uniform,
-                            has_dynamic_offset: false,
-                            min_binding_size: None,
-                        },
-                        count: None,
-                    },
-                    wgpu::BindGroupLayoutEntry {
-                        binding: 1,
-                        visibility: wgpu::ShaderStages::VERTEX | wgpu::ShaderStages::FRAGMENT,
-                        ty: wgpu::BindingType::Buffer {
-                            ty: wgpu::BufferBindingType::Uniform,
-                            has_dynamic_offset: false,
-                            min_binding_size: None,
-                        },
-                        count: None,
-                    },
-                ],
+                entries: &[],
             });
 
         Self {
             surface,
             device,
             queue,
-            config,
+            sc_desc,
+            swap_chain,
             size,
 
             texture_bind_group_layout,
-            default_uniform_bind_group_layout,
+            uniform_bind_group_layout,
 
             shaders: Vec::new(),
             vertex_buffers: Vec::new(),
@@ -118,17 +98,13 @@ impl Renderer {
 
     pub(crate) fn resize(&mut self, new_size: winit::dpi::PhysicalSize<u32>) {
         self.size = new_size;
-        self.config.width = new_size.width;
-        self.config.height = new_size.height;
-        self.surface.configure(&self.device, &self.config);
+        self.sc_desc.width = new_size.width;
+        self.sc_desc.height = new_size.height;
+        self.swap_chain = self.device.create_swap_chain(&self.surface, &self.sc_desc);
     }
 
-    pub(crate) fn render(&mut self) -> Result<(), wgpu::SurfaceError> {
-        let frame = self.surface.get_current_frame()?.output;
-        let view = frame
-            .texture
-            .create_view(&wgpu::TextureViewDescriptor::default());
-
+    pub(crate) fn render(&mut self) -> Result<(), wgpu::SwapChainError> {
+        let frame = self.swap_chain.get_current_frame()?.output;
         let mut encoder = self
             .device
             .create_command_encoder(&wgpu::CommandEncoderDescriptor {
@@ -138,7 +114,7 @@ impl Renderer {
         let mut render_pass = encoder.begin_render_pass(&wgpu::RenderPassDescriptor {
             label: Some("Render pass"),
             color_attachments: &[wgpu::RenderPassColorAttachment {
-                view: &view,
+                view: &frame.view,
                 resolve_target: None,
                 ops: wgpu::Operations {
                     load: wgpu::LoadOp::Clear(wgpu::Color::BLACK),
@@ -148,33 +124,13 @@ impl Renderer {
             depth_stencil_attachment: None,
         });
 
-        let mut already_loaded_shader: usize = 0;
+        let mut already_loaded_shader: usize = 5;
         let mut already_loaded_buffer: usize = 5;
-        let mut already_loaded_texture: usize = 0;
-        let mut already_loaded_uniform_buffer: usize = 0;
-
-        render_pass.set_bind_group(
-            1,
-            self.uniform_bind_group
-                .get(0)
-                .expect("Couldn't find the camera uniform data"),
-            &[],
-        );
-        render_pass.set_pipeline(
-            self.shaders
-                .get(0)
-                .expect("Couldn't find the default shader"),
-        );
-        render_pass.set_bind_group(
-            0,
-            self.texture_bind_group
-                .get(0)
-                .expect("Couldn't find the default texture"),
-            &[],
-        );
+        let mut already_loaded_texture: usize = 5;
+        let mut already_loaded_uniform_buffer: usize = 5;
 
         for i in self.render_pipelines.iter() {
-            if already_loaded_shader != i.shader_index.clone() || i.shader_index.clone() >= 1 {
+            if already_loaded_shader != i.shader_index.clone() || i.shader_index.clone() == 0 {
                 render_pass.set_pipeline(
                     self.shaders.get(i.shader_index.clone()).expect(
                         format!("Couldn't find shader at index: {}", i.shader_index).as_str(),
@@ -183,16 +139,15 @@ impl Renderer {
                 already_loaded_shader = i.shader_index;
             }
 
-            if already_loaded_texture != i.texture_index.clone() || i.texture_index.clone() >= 1 {
-                render_pass.set_bind_group(
-                    1,
-                    self.texture_bind_group
-                        .get(i.texture_index.clone())
-                        .unwrap(),
-                    &[],
-                );
-                already_loaded_texture = i.texture_index;
-            }
+                if already_loaded_texture != i.texture_index.clone() || i.texture_index.clone() == 0 {
+                    render_pass.set_bind_group(
+                        0,
+                        self.texture_bind_group.get(i.texture_index.clone()).unwrap(),
+                        &[],
+                    );
+                    already_loaded_texture = i.texture_index;
+                }
+
 
             if i.uniform_index.is_some() {
                 let uniform_buffer_index = i.uniform_index.clone().unwrap();
@@ -207,9 +162,9 @@ impl Renderer {
                         .as_str(),
                     );
                     if already_loaded_uniform_buffer != uniform_buffer_index.clone()
-                        || uniform_buffer_index.clone() == 1
+                        || uniform_buffer_index.clone() == 0
                     {
-                        render_pass.set_bind_group(2, uniform_buffer, &[]);
+                        render_pass.set_bind_group(1, uniform_buffer, &[]);
                         already_loaded_uniform_buffer = uniform_buffer_index;
                     }
                 }
