@@ -4,7 +4,7 @@
  * The license is same as the one on the root.
 */
 
-use crate::{header::{}, objects};
+use crate::{definitions::{}, objects};
 use std::collections::BTreeMap;
 
 #[derive(Debug, Clone, Copy)]
@@ -42,7 +42,8 @@ impl Text {
         &mut self,
         content: &str,
         position: (u8, u8),
-        engine: &mut crate::header::Engine,
+        engine: &mut crate::definitions::Engine,
+        camera: crate::utils::camera::Camera,
     ) -> anyhow::Result<()> {
         //let mut chars = Vec::<Vertex>::new();
         for i in content.char_indices() {
@@ -52,7 +53,7 @@ impl Text {
                 None => character = self.font.rasterize(i.1, self.size),
             }
 
-            let character_shape_index = objects::square(Some("text"), engine)?;
+            let character_shape_index = objects::square(Some("text"), engine, camera)?;
             let character_shape = engine.get_object(character_shape_index)?;
             character_shape.resize(character.0.width as f32, character.0.height as f32, 0.0);
         }
